@@ -7,16 +7,26 @@ echo Building operator bundle image:
 echo
 
 BUNDLE=rhpam-operator-bundle
+ENVDIR=olm-catalog/test
+BUNDLE_NAME=rhpam-7/${BUNDLE}
+VERSION=$(go run getversion.go)
+CSV=businessautomation-operator.${VERSION}.clusterserviceversion.yaml
+if [[ ${DEV} == true ]]; then
+    ENVDIR=olm-catalog/dev
+    BUNDLE_NAME=quay.io/tchughesiv/${BUNDLE}
+fi
 CFLAGS="docker --no-squash"
 if [[ ${LOCAL} != true ]]; then
     CFLAGS="osbs"
     if [[ ${1} == "release" ]]; then
         CFLAGS+=" --release"
+        ENVDIR=olm-catalog/prod
     fi
 fi
 
 echo ${CFLAGS}
 
+VERSION=$(go run getversion.go)
 CSVVERSION=$(go run getversion.go -csv)
 
 OLMDIR=deploy/olm-catalog/prod
@@ -28,9 +38,9 @@ if [[ ${DEV} == true ]]; then
 fi
 VERDIR=${OLMDIR}/${CSVVERSION}
 CRD=kieapp.crd.yaml
-if (( $(echo "${CSVVERSION} 7.9.0" | awk '{print ($1 < $2)}') )); then
-    CRD=kieapp.crd.v1beta1.yaml
-fi
+#if (( $(echo "${VERSION} 7.9.0" | awk '{print ($1 < $2)}') )); then
+#    CRD=kieapp.crd.v1beta1.yaml
+#fi
 ANNO=annotations.yaml
 CSV_PATH=${VERDIR}/manifests/${CSV}
 CRD_PATH=${VERDIR}/manifests/${CRD}
@@ -51,7 +61,7 @@ cekit-cache add --md5 ${MD5_ANNO} ${ANNO_PATH}
 
 cekit -v --descriptor image-bundle.yaml --redhat build \
     --overrides '{name: '${BUNDLE_NAME}'}' \
-    --overrides '{version: '${CSVVERSION}'}' \
+    --overrides '{version: '${VERSION}'}' \
     --overrides '{
 artifacts: [
     {name: '${CSV}', path: '${CSV_PATH}', md5: '${MD5_CSV}', dest: '/manifests'},
@@ -62,10 +72,11 @@ artifacts: [
 "osbs":
     {
     "configuration":
-        {"container":
+        {
+        "container":
             {
             "operator_manifests":
-                {"enable_digest_pinning": false, "enable_repo_replacements": false, "enable_registry_replacements": false, "manifests_dir": 'modules/olm-catalog/${CSVVERSION}/manifests'},
+                {"enable_digest_pinning": true, "enable_repo_replacements": true, "enable_registry_replacements": true, "manifests_dir": 'modules/olm-catalog/prod/${CSVVERSION}/manifests'},
             "platforms":
                 {"only": ["x86_64"]}
             }
@@ -75,14 +86,3 @@ artifacts: [
     }
 }' \
     ${CFLAGS}
-
-#
-#    --overrides '{
-#"modules": {
-#    "repositories": [
-#        {"name": "olm-catalog", "path": '${OLMDIR}'}
-#    ],
-#    "install": [
-#        {"name": "olm-catalog"}
-#    ]}
-#}' \
